===========
Werewolves!
===========

Werewolves! is a party game sometimes called "Mafia".  There are many variations.
This game is based in part on a card game adaption.

The players are randomly assigned roles of either villagers or werewolves.  3 additional
roles are dealt to the table.
At night, some of the villagers with special roles and all the werewolves wake up at different
times and perform certain actions.  After all the night phases are done, the players
may discuss what happend during the night, though they may not actually show each other
their cards.  A player may say the role she received, but she may also claim that she
were dealt a role that she did not receive.

After the discussion, all the players vote for a player to eliminate.  If there is a
player or players who received more than 1 vote, the player(s) with the most votes
are eliminated and the actual roles the players now posess are revealed.  If a
werewolf was killed, the village team wins, even if an innocent villager was eliminated,
too.  The villagers may also win if no one is eliminated and all the werewolves are in
the middle of the table.

See full documentation at http://txwerewolves.readthedocs.io/

